@@ -10,5 +10,6 @@ void restore_state(void);
 void save_state(void);
 void text_mode(void);
 int check_console(void);
-
+int enable_vga(void);
+int disable_vga(void);
 
